==> ginkgo-hpc-docs-1.9.0-4-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Ginkgo", "index.html", [
    [ "Tutorial", "^https://github.com/ginkgo-project/ginkgo/wiki/Tutorial:-Building-a-Poisson-Solver", null ],
    [ "Examples", "Examples.html", null ],
    [ "Publications", "citing_ginkgo.html", null ],
    [ "Citing Ginkgo", "citing_ginkgo.html", null ],
    [ "Ginkgo White Paper", "^https://www.arxiv-vanity.com/papers/2006.16852/", null ],
    [ "Slides and Outreach", "^https://github.com/ginkgo-project/outreach", null ],
    [ "Contributing To Ginkgo", "contributing_guidelines.html", null ],
    [ "Using Ginkgo", "install_ginkgo.html", null ],
    [ "Installing Ginkgo", "install_ginkgo.html", null ],
    [ "Testing Ginkgo", "testing_ginkgo.html", null ],
    [ "Benchmarking Ginkgo", "benchmarking_ginkgo.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Installation Instructions", "install_ginkgo.html", null ],
    [ "Testing Instructions", "testing_ginkgo.html", null ],
    [ "Running the benchmarks", "benchmarking_ginkgo.html", null ],
    [ "Contributing guidelines", "contributing_guidelines.html", [
      [ "Table of Contents", "contributing_guidelines.html#autotoc_md18", null ],
      [ "Most important stuff (A TL;DR)", "contributing_guidelines.html#autotoc_md19", null ],
      [ "Project structure", "contributing_guidelines.html#autotoc_md20", [
        [ "Extended header files", "contributing_guidelines.html#autotoc_md21", null ],
        [ "Using library classes", "contributing_guidelines.html#autotoc_md22", null ]
      ] ],
      [ "Git related", "contributing_guidelines.html#autotoc_md23", [
        [ "Our git workflow", "contributing_guidelines.html#autotoc_md24", null ],
        [ "Writing good commit messages", "contributing_guidelines.html#autotoc_md25", [
          [ "Attributing credit", "contributing_guidelines.html#autotoc_md26", null ]
        ] ],
        [ "Creating, Reviewing and Merging Pull Requests", "contributing_guidelines.html#autotoc_md27", null ]
      ] ],
      [ "Code style", "contributing_guidelines.html#autotoc_md28", [
        [ "Automatic code formatting", "contributing_guidelines.html#autotoc_md29", null ],
        [ "Naming scheme", "contributing_guidelines.html#autotoc_md30", [
          [ "Filenames", "contributing_guidelines.html#autotoc_md31", null ],
          [ "Macros", "contributing_guidelines.html#autotoc_md32", null ],
          [ "Variables", "contributing_guidelines.html#autotoc_md33", null ],
          [ "Constants", "contributing_guidelines.html#autotoc_md34", null ],
          [ "Functions", "contributing_guidelines.html#autotoc_md35", null ],
          [ "Structures and classes", "contributing_guidelines.html#autotoc_md36", null ],
          [ "Members", "contributing_guidelines.html#autotoc_md37", null ],
          [ "Namespaces", "contributing_guidelines.html#autotoc_md38", null ],
          [ "Template parameters", "contributing_guidelines.html#autotoc_md39", null ]
        ] ],
        [ "Whitespace", "contributing_guidelines.html#autotoc_md40", null ],
        [ "Include statement grouping", "contributing_guidelines.html#autotoc_md41", [
          [ "Main header", "contributing_guidelines.html#autotoc_md42", null ],
          [ "Some general comments.", "contributing_guidelines.html#autotoc_md43", null ]
        ] ],
        [ "Other Code Formatting not handled by ClangFormat", "contributing_guidelines.html#autotoc_md44", [
          [ "Control flow constructs", "contributing_guidelines.html#autotoc_md45", null ],
          [ "Variable declarations", "contributing_guidelines.html#autotoc_md46", null ]
        ] ],
        [ "CMake coding style", "contributing_guidelines.html#autotoc_md47", [
          [ "Whitespaces", "contributing_guidelines.html#autotoc_md48", null ],
          [ "Use of macros vs functions", "contributing_guidelines.html#autotoc_md49", null ],
          [ "Naming style", "contributing_guidelines.html#autotoc_md50", null ]
        ] ]
      ] ],
      [ "Helper scripts", "contributing_guidelines.html#autotoc_md51", [
        [ "Create a new algorithm", "contributing_guidelines.html#autotoc_md52", null ],
        [ "Converting CUDA code to HIP code", "contributing_guidelines.html#autotoc_md53", null ]
      ] ],
      [ "Writing Tests", "contributing_guidelines.html#autotoc_md54", [
        [ "Testing know-how", "contributing_guidelines.html#autotoc_md55", null ],
        [ "Some general rules.", "contributing_guidelines.html#autotoc_md56", null ],
        [ "Writing tests for kernels", "contributing_guidelines.html#autotoc_md57", null ]
      ] ],
      [ "Documentation style", "contributing_guidelines.html#autotoc_md58", [
        [ "Developer targeted notes", "contributing_guidelines.html#autotoc_md59", null ],
        [ "Whitespaces", "contributing_guidelines.html#autotoc_md60", [
          [ "After named tags such as @param foo", "contributing_guidelines.html#autotoc_md61", null ]
        ] ],
        [ "Documenting examples", "contributing_guidelines.html#autotoc_md62", null ]
      ] ],
      [ "Other programming comments", "contributing_guidelines.html#autotoc_md63", [
        [ "C++ standard stream objects", "contributing_guidelines.html#autotoc_md64", null ],
        [ "Warnings", "contributing_guidelines.html#autotoc_md65", null ],
        [ "Avoiding circular dependencies", "contributing_guidelines.html#autotoc_md66", null ]
      ] ]
    ] ],
    [ "Citing Ginkgo", "citing_ginkgo.html", null ],
    [ "Example programs", "Examples.html", null ],
    [ "The adaptiveprecision-blockjacobi program", "adaptiveprecision_blockjacobi.html", null ],
    [ "The batched-solver program", "batched_solver.html", null ],
    [ "The cb-gmres program", "cb_gmres.html", null ],
    [ "The custom-logger program", "custom_logger.html", null ],
    [ "The custom-matrix-format program", "custom_matrix_format.html", null ],
    [ "The custom-stopping-criterion program", "custom_stopping_criterion.html", null ],
    [ "The distributed-solver program", "distributed_solver.html", null ],
    [ "The external-lib-interfacing program", "external_lib_interfacing.html", null ],
    [ "The file-config-solver program", "file_config_solver.html", null ],
    [ "The ginkgo-overhead program", "ginkgo_overhead.html", null ],
    [ "The ginkgo-ranges program", "ginkgo_ranges.html", null ],
    [ "The heat-equation program", "heat_equation.html", null ],
    [ "The ilu-preconditioned-solver program", "ilu_preconditioned_solver.html", null ],
    [ "The inverse-iteration program", "inverse_iteration.html", null ],
    [ "The ir-ilu-preconditioned-solver program", "ir_ilu_preconditioned_solver.html", null ],
    [ "The iterative-refinement program", "iterative_refinement.html", null ],
    [ "The kokkos-assembly program", "kokkos_assembly.html", null ],
    [ "The minimal-cuda-solver program", "minimal_cuda_solver.html", null ],
    [ "The mixed-multigrid-preconditioned-solver program", "mixed_multigrid_preconditioned_solver.html", null ],
    [ "The mixed-multigrid-solver program", "mixed_multigrid_solver.html", null ],
    [ "The mixed-precision-ir program", "mixed_precision_ir.html", null ],
    [ "The mixed-spmv program", "mixed_spmv.html", null ],
    [ "The multigrid-preconditioned-solver program", "multigrid_preconditioned_solver.html", null ],
    [ "The multigrid-preconditioned-solver-customized program", "multigrid_preconditioned_solver_customized.html", null ],
    [ "The nine-pt-stencil-solver program", "nine_pt_stencil_solver.html", null ],
    [ "The papi-logging program", "papi_logging.html", null ],
    [ "The par-ilu-convergence program", "par_ilu_convergence.html", null ],
    [ "The performance-debugging program", "performance_debugging.html", null ],
    [ "The poisson-solver program", "poisson_solver.html", null ],
    [ "The preconditioned-solver program", "preconditioned_solver.html", null ],
    [ "The preconditioner-export program", "preconditioner_export.html", null ],
    [ "The reordered-preconditioned-solver program", "reordered_preconditioned_solver.html", null ],
    [ "The schroedinger-splitting program", "schroedinger_splitting.html", null ],
    [ "The simple-solver program", "simple_solver.html", null ],
    [ "The simple-solver-logging program", "simple_solver_logging.html", null ],
    [ "The three-pt-stencil-solver program", "three_pt_stencil_solver.html", null ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Ginkgo", "^https://ginkgo-project.github.io/", null ]
  ] ]
];

var NAVTREEINDEX =
[
"Examples.html",
"classgko_1_1NotCompiled.html#aa85feba061f17a192a47f238a5bb4a32",
"classgko_1_1config_1_1pnode.html#a6a15e501427aec38f5950dce193ffdb9",
"classgko_1_1experimental_1_1mpi_1_1communicator.html#ab769309228bcbff10cdf798d07c68bdd",
"classgko_1_1log_1_1ProfilerHook.html#a21ba3bcec189367adec6638f062f68e8",
"classgko_1_1range.html",
"functions_func_~.html",
"namespacegko_1_1factorization.html#a42430a5d93539c24303273804684ef67",
"structgko_1_1default__converter.html#aeeb535f41abb975f20857989c8ac2470",
"structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';

==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Ginkgo", "index.html", [
    [ "Tutorial", "^https://github.com/ginkgo-project/ginkgo/wiki/Tutorial:-Building-a-Poisson-Solver", null ],
    [ "Examples", "Examples.html", null ],
    [ "Publications", "citing_ginkgo.html", null ],
    [ "Citing Ginkgo", "citing_ginkgo.html", null ],
    [ "Ginkgo White Paper", "^https://www.arxiv-vanity.com/papers/2006.16852/", null ],
    [ "Slides and Outreach", "^https://github.com/ginkgo-project/outreach", null ],
    [ "Contributing To Ginkgo", "contributing_guidelines.html", null ],
    [ "Using Ginkgo", "install_ginkgo.html", null ],
    [ "Installing Ginkgo", "install_ginkgo.html", null ],
    [ "Testing Ginkgo", "testing_ginkgo.html", null ],
    [ "Benchmarking Ginkgo", "benchmarking_ginkgo.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Installation Instructions", "install_ginkgo.html", null ],
    [ "Testing Instructions", "testing_ginkgo.html", null ],
    [ "Running the benchmarks", "benchmarking_ginkgo.html", null ],
    [ "Contributing guidelines", "contributing_guidelines.html", [
      [ "Table of Contents", "contributing_guidelines.html#autotoc_md18", null ],
      [ "Most important stuff (A TL;DR)", "contributing_guidelines.html#autotoc_md19", null ],
      [ "Project structure", "contributing_guidelines.html#autotoc_md20", [
        [ "Extended header files", "contributing_guidelines.html#autotoc_md21", null ],
        [ "Using library classes", "contributing_guidelines.html#autotoc_md22", null ]
      ] ],
      [ "Git related", "contributing_guidelines.html#autotoc_md23", [
        [ "Our git workflow", "contributing_guidelines.html#autotoc_md24", null ],
        [ "Writing good commit messages", "contributing_guidelines.html#autotoc_md25", [
          [ "Attributing credit", "contributing_guidelines.html#autotoc_md26", null ]
        ] ],
        [ "Creating, Reviewing and Merging Pull Requests", "contributing_guidelines.html#autotoc_md27", null ]
      ] ],
      [ "Code style", "contributing_guidelines.html#autotoc_md28", [
        [ "Automatic code formatting", "contributing_guidelines.html#autotoc_md29", null ],
        [ "Naming scheme", "contributing_guidelines.html#autotoc_md30", [
          [ "Filenames", "contributing_guidelines.html#autotoc_md31", null ],
          [ "Macros", "contributing_guidelines.html#autotoc_md32", null ],
          [ "Variables", "contributing_guidelines.html#autotoc_md33", null ],
          [ "Constants", "contributing_guidelines.html#autotoc_md34", null ],
          [ "Functions", "contributing_guidelines.html#autotoc_md35", null ],
          [ "Structures and classes", "contributing_guidelines.html#autotoc_md36", null ],
          [ "Members", "contributing_guidelines.html#autotoc_md37", null ],
          [ "Namespaces", "contributing_guidelines.html#autotoc_md38", null ],
          [ "Template parameters", "contributing_guidelines.html#autotoc_md39", null ]
        ] ],
        [ "Whitespace", "contributing_guidelines.html#autotoc_md40", null ],
        [ "Include statement grouping", "contributing_guidelines.html#autotoc_md41", [
          [ "Main header", "contributing_guidelines.html#autotoc_md42", null ],
          [ "Some general comments.", "contributing_guidelines.html#autotoc_md43", null ]
        ] ],
        [ "Other Code Formatting not handled by ClangFormat", "contributing_guidelines.html#autotoc_md44", [
          [ "Control flow constructs", "contributing_guidelines.html#autotoc_md45", null ],
          [ "Variable declarations", "contributing_guidelines.html#autotoc_md46", null ]
        ] ],
        [ "CMake coding style", "contributing_guidelines.html#autotoc_md47", [
          [ "Whitespaces", "contributing_guidelines.html#autotoc_md48", null ],
          [ "Use of macros vs functions", "contributing_guidelines.html#autotoc_md49", null ],
          [ "Naming style", "contributing_guidelines.html#autotoc_md50", null ]
        ] ]
      ] ],
      [ "Helper scripts", "contributing_guidelines.html#autotoc_md51", [
        [ "Create a new algorithm", "contributing_guidelines.html#autotoc_md52", null ],
        [ "Converting CUDA code to HIP code", "contributing_guidelines.html#autotoc_md53", null ]
      ] ],
      [ "Writing Tests", "contributing_guidelines.html#autotoc_md54", [
        [ "Testing know-how", "contributing_guidelines.html#autotoc_md55", null ],
        [ "Some general rules.", "contributing_guidelines.html#autotoc_md56", null ],
        [ "Writing tests for kernels", "contributing_guidelines.html#autotoc_md57", null ]
      ] ],
      [ "Documentation style", "contributing_guidelines.html#autotoc_md58", [
        [ "Developer targeted notes", "contributing_guidelines.html#autotoc_md59", null ],
        [ "Whitespaces", "contributing_guidelines.html#autotoc_md60", [
          [ "After named tags such as <span class=\"tt\">@param foo</span>", "contributing_guidelines.html#autotoc_md61", null ]
        ] ],
        [ "Documenting examples", "contributing_guidelines.html#autotoc_md62", null ]
      ] ],
      [ "Other programming comments", "contributing_guidelines.html#autotoc_md63", [
        [ "C++ standard stream objects", "contributing_guidelines.html#autotoc_md64", null ],
        [ "Warnings", "contributing_guidelines.html#autotoc_md65", null ],
        [ "Avoiding circular dependencies", "contributing_guidelines.html#autotoc_md66", null ]
      ] ]
    ] ],
    [ "Citing Ginkgo", "citing_ginkgo.html", null ],
    [ "Example programs", "Examples.html", null ],
    [ "The adaptiveprecision-blockjacobi program", "adaptiveprecision_blockjacobi.html", null ],
    [ "The batched-solver program", "batched_solver.html", null ],
    [ "The cb-gmres program", "cb_gmres.html", null ],
    [ "The custom-logger program", "custom_logger.html", null ],
    [ "The custom-matrix-format program", "custom_matrix_format.html", null ],
    [ "The custom-stopping-criterion program", "custom_stopping_criterion.html", null ],
    [ "The distributed-multigrid-preconditioned-solver program", "distributed_multigrid_preconditioned_solver.html", null ],
    [ "The distributed-solver program", "distributed_solver.html", null ],
    [ "The external-lib-interfacing program", "external_lib_interfacing.html", null ],
    [ "The file-config-solver program", "file_config_solver.html", null ],
    [ "The ginkgo-overhead program", "ginkgo_overhead.html", null ],
    [ "The ginkgo-ranges program", "ginkgo_ranges.html", null ],
    [ "The heat-equation program", "heat_equation.html", null ],
    [ "The ilu-preconditioned-solver program", "ilu_preconditioned_solver.html", null ],
    [ "The inverse-iteration program", "inverse_iteration.html", null ],
    [ "The ir-ilu-preconditioned-solver program", "ir_ilu_preconditioned_solver.html", null ],
    [ "The iterative-refinement program", "iterative_refinement.html", null ],
    [ "The kokkos-assembly program", "kokkos_assembly.html", null ],
    [ "The minimal-cuda-solver program", "minimal_cuda_solver.html", null ],
    [ "The mixed-multigrid-preconditioned-solver program", "mixed_multigrid_preconditioned_solver.html", null ],
    [ "The mixed-multigrid-solver program", "mixed_multigrid_solver.html", null ],
    [ "The mixed-precision-ir program", "mixed_precision_ir.html", null ],
    [ "The mixed-spmv program", "mixed_spmv.html", null ],
    [ "The multigrid-preconditioned-solver program", "multigrid_preconditioned_solver.html", null ],
    [ "The multigrid-preconditioned-solver-customized program", "multigrid_preconditioned_solver_customized.html", null ],
    [ "The nine-pt-stencil-solver program", "nine_pt_stencil_solver.html", null ],
    [ "The papi-logging program", "papi_logging.html", null ],
    [ "The par-ilu-convergence program", "par_ilu_convergence.html", null ],
    [ "The performance-debugging program", "performance_debugging.html", null ],
    [ "The poisson-solver program", "poisson_solver.html", null ],
    [ "The preconditioned-solver program", "preconditioned_solver.html", null ],
    [ "The preconditioner-export program", "preconditioner_export.html", null ],
    [ "The reordered-preconditioned-solver program", "reordered_preconditioned_solver.html", null ],
    [ "The schroedinger-splitting program", "schroedinger_splitting.html", null ],
    [ "The simple-solver program", "simple_solver.html", null ],
    [ "The simple-solver-logging program", "simple_solver_logging.html", null ],
    [ "The three-pt-stencil-solver program", "three_pt_stencil_solver.html", null ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Ginkgo", "^https://ginkgo-project.github.io/", null ]
  ] ]
];

var NAVTREEINDEX =
[
"Examples.html",
"classgko_1_1NotCompiled.html#aa85feba061f17a192a47f238a5bb4a32",
"classgko_1_1config_1_1pnode.html#a3b5eac91e5865801b16dd346b47fa0d2",
"classgko_1_1experimental_1_1mpi_1_1DenseCommunicator.html#a33a2a971df99faf4fb41940a79720691",
"classgko_1_1experimental_1_1reorder_1_1Rcm.html#a1dc8890f88e6a7786a10ad93d40fb06d",
"classgko_1_1log_1_1profiling__scope__guard.html#af73538d396030074e0840682420433c6",
"contributing_guidelines.html#autotoc_md57",
"namespacegko.html#a5e379ed0d74e7c7f8c33fbfe6816e697",
"simple_solver.html",
"structgko_1_1log_1_1linop__data.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
